Monty Python's Flying Circus: Just the Words - Episode 34

# Episode Thirty-four: The Cycling Tour

Mr Pither
Accidents involving food
Clodagh Rodgers
Trotsky
Smolensk
Bingo-crazed Chinese
'Russian 42nd International Clambake'
'Jack in a Box'

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| The green lush Devon countryside. Theme music. The camera is tracking along a hedgerow beside the road. We see a head whizzing along, sometimes just above the hedgerow and sometimes bobbing out of sight, accasionally for long periods.
| SUPERIMPOSED CAPTION: 'THE CYCLING TOUR'
| Mr. Pither, the cyclist, bobs up and down a few more times, then disappears from sight. There is a crash and clang of a bicycle in collision, mixed with the scream of a frightened hen, and stifled shout of alarm. We are still in long shot and see nothing. The music stops abruptly on the crash.
Pither | (voice over) August 18th. Fell off near Bovey Tracey. The pump caught in my trouser leg.
| Cut to interior of a transport cafe. A rather surly proprietor with fag in mouth is operating an Espresso coffee machine. Pither, a fussy bespectacled little man, in sweater, trousers, is leaning over the counter, talking chattily.
Pither | The pump caught in my trouser leg, and my sandwiches were badly crushed.
Proprietor | 35p please.
| He goes back to working the machine.
Pither | These sandwiches, however, were an excellent substitute.
| Enormous lorry driver comes up to counter.
Driver | Give us ten woods, Barney.
Pither | Hello! (the lorry driver looks at him without interest) It's funny how one can go through life, as I have, disliking bananas and being indifferent to cheese, and then be able to eat, and enjoy, a banana and cheese sandwich like this. (the driver goes off with his cigarettes)
Proprietor | 35p please.
Pither | Ah! I have only a fifty. Do you have change?
Proprietor | (with heavy sarcasm) Well I'll have a look, but I may have to go to the bank.
Pither | I'm most awfully sorry.
Proprietor | (handing him change) 15p.
Pither | Oh, what a stroke of luck. Well, all the very best. (Pither proffers his hand, the proprietor ignores it) And thank you again for the excellent banana and cheese delicacy.
| He exits busily. The proprietor looks after him. Cut to hedgerows. Theme music. Pither's head bobbing up and down. At the same point in the music it disappears and there is a crash mingled with grunting of pig.
Pither | (voice over) August 23rd. Fell off near Budleigh Salterton.
| A brief shot of an unindentifiable animated Gilliam monster looking over the top of a hedge. Cut to a woman gardening. Behind her we see Pither's head peering over the hedge.
Pither | ...and the pump caught in my trouser leg...(she carries on digging trying to ignore him) ...and that's how they were damaged...(no reaction)...the eggs...you remember...the hard-boiled eggs I was telling you about...they were in a tupperware container, reputedly self-sealing, which fell open upon contact with the tarmacadam surface of the road.... (she goes on digging)...the B489...the Dawlish road...(again no reaction) That shouldn't really happen to a self-sealing container, should it? What do you keep your hard-boiled eggs in?
| The lady gardener goes back into house. Pither waits for a few moments.
Pither | (shouting) I think in future I shall lash them to the handlebars with adhesive tape...this should obviate a recurrence of the same problem...well I can't stop here all day...I'm on a cycling tour of North Cornwall. Must be off.
| Cut to hedgerows again. Pither's head bowling along. Theme music. He dips out of sight. Crash and a cow moos.
Pither | (voice over) August 26th. Fell off near Ottery St Mary. The pump caught in my trouser leg. Decided to wear short trousers from now on.
| Another brief shot of the animated monster peeking over a hedgerow. Cut to another hedgerow. Pither's head bowling along. Short burst of music. Crash.
Pither | (voice over) Fell off near Tiverton. Perhaps a shorter pump is the answer.
| Another monster peeps briefly. Cut to a tiny village high street, deserted save for an old lady. Pither cycles into shot. He is in shorts, but still has his bicycle clips on. He approaches the old lady.
Pither | Excuse me, madam, I wonder if you could tell me of a good bicycle shop in this village, where I could find either a means of adapting my present pump, or failing that, purchase a replacement?
Old lady | There's only one shop here.
| She points with a shaking finger. Camera pans very slightly to one side to reveal a shop with a huge four-foot-high sign: 'Bicycle Pump Centre - Specialists In Shorter Bicycle Pumps'. Another sign: 'Short Pumps Available Here'. Another sign: 'We Shorten Pumps While-U-Wait'. The camera shows the shop only for a couple of seconds and pans back to the old lady and Pither.
Pither | What a stroke of luck. Now perhaps cycling will become less precarious.
| Cut to interior of doctor's surgery. There is a knock on the door..
Doctor | Yes? (a nurse puts her head round the door)
Nurse | A Mr Pither to see you, doctor. His bicycle pump got caught in his sock.
Doctor | Oh, thank you nurse, show him in please.
Nurse | This way, please.
| The nurse exits, Pither enters in shorts and sweater.
Doctor | Morning.
Pither | Oh, a very good morning to you too, Doctor
Doctor | Ah, I understand you had an accident?
Pither | Yes, my pump got...
Doctor | ...caught in your sock.
Pither | Absolutely. Yes. My fruit cake was damaged on one side.
Doctor | Well...
Pither | It's got grit all over it.
Doctor | Well now, are you in pain?
Pither | Oh, heavens no.
Doctor | Ah well, where were you hurt?
Pither | Oh, fortunately, I escaped without injury.
Doctor | Well what is the trouble?
Pither | Please, could you tell me the way to Iddesleigh?
Doctor | I'm a doctor, you know.
Pither | Oh yes, absolutely. Normally I would have asked a policeman or a minister of the Church, but finding no one available, I thought it better to consult a man with some professional qualifications, rather than rely on the possibly confused testimony of a passer-by.
Doctor | Oh alright. (he scribbles something on a piece of paper and hands it to Pither) Take this to a chemist.
Pither | Thank you.
| Cut to exterior of a chemist's shop. A chemist comes out holding the paper and points up the street. Pither thanks him and mounts his bike. Cut to the hedgerows again. Pither's head. Theme music reaches the point where Pither normally falls off, his head disappears, the music cuts off. There is no crash. Suddenly Pither's head reappears further on and the music starts up again.
Pither | (voice over) September 2nd. Did not fall off outside Iddesley.
| Cut to a small market town. A line of cars. Pither's head just above roofs of cars. Theme music. He suddenly disappears, the music stops and there is a crash.
Pither | (voice over) Fell off in Tavistock.
| Cut to a discreet corner of a Watney's pub. Soft music. A middle-aged businessman and a sexy secretary who obviously want to be alone are sitting huddled over a table. At the next table is Pither, with half-pint in front of him.
Pither | My foot caught in my trouser leg and that's how the bottle broke.
Girl | Tell her today, you could ring her.
Man | I can't. I can't.
Pither | I said you'd never guess.
Man | Sixteen years we've been together. I can't just ring her up.
Girl | Well, if you can't do it now, you never will.
Pither | (tapping the man on the leg) Do you like Tizer?
Man | (to Pither) What? No. No.
Girl | Do you want me or not, James? It's your decision.
Pither | I suppose it is still available in this area, is it?
Girl | Do you want me or not, James?
Man | What?
Pither | Tizer.
Girl | Yes or no.
Pither | Is it still available in this area?
Man | (to Pither) I don't know.
Girl | I see, in that case it's goodbye for ever, James.
Man | No! I mean yes!
Pither | Oh it is, is it?
Man | (to Pither) No.
Girl | Oh! You never could make up your mind.
Man | I can.... I have....
Girl | (taking off ring) Goodbye James.
| She runs out sobbing.
Man | No wait, Lucille!
Pither | Does your lovely daughter like Tizer? Eh?
Man | Lucille!
Pither | Wouldn't mind buying her a bottle of Tizer.... if it's available in this area, that is.
Man | (turning on Pither) Would you like me to show you the door?
Pither | Oh, that's extremely kind of you, but I saw it on the way in.
Man | You stupid, interfering little rat.
Pither | Oh! The very words of the garage mechanic in Bude!
| The man picks Pither up by the scruff of the neck and the seat of his pants. He carries him bodily towards the door.
Pither | I had just fallen off my bicycle, this is most kind of you, and my lemon curd tartlet had...
Man | Damn your lemon curd tartlet!
| Pither is thrown out. He picks himself up and sees girl outside sobbing.
Pither | Just had a chat with your dad.
| Girl bursts into further tears. Whistling cheerfully, Pither gets on his bicycle and, happier than he has been for a long time, he cycles off down the road and round a corner. Sounds of car-tyre screech and crash of Pither going straight into a car. Cut to interior of car speeding along highway. Pither is sitting in the back seat with his bicycle. The driver, Mr Gulliver, talks with a professional precision.
Pither | My rubber instep caught on the rear mudguard stanchion and...
Gulliver | Really? And what happened to the corned beef rolls?
Pither | The corned beef rolls squashed out of all...here, how did you know about the corned beef rolls?
Gulliver | I noticed them - or what remained of them - in the road. I noticed also that the lemon curd tart had sustained some superficial damage.
Pither | That's right. The curd had become...
Gulliver | Detached from the pastry base.
Pither | (with some surprise) Absolutely right, yes.
Gulliver | Otherwise the contents of the sandwich box were relatively unharmed, although I detected small particles of bitumen in the chocolate kup kakes.
Pither | But they were wrapped in foil!
Gulliver | Not the hard chocolate top, I'm afraid.
Pither | Oh, that's the bit I like.
Gulliver | The sausage roll, the crisps and ginger bisquit were unscathed.
Pither | How do you know so much about cycling?
Gulliver | Well, I'm making a special study of accidents involving food.
Pither | Really?
Gulliver | Yes, do you know that in our laboratories, we have developed a cheese sandwich that can withstand an impact of 4,000 pounds per square inch?
Pither | Good heavens!
Gulliver | Amazing, isn't it? We have also developed a tomato which can eject itself when an accident is imminent.
Pither | Even if it's inside an egg and tomato roll?
Gulliver | Anywhere! Even if it's in your stomach, and it senses an accident it will come up your throat and out of the window. Do you realise what this means?
Pither | Safer food?
Gulliver | Exactly! No longer will food be squashed, crushed and damaged, by the ignorance and stupidity of the driver! (becoming slightly messianic) Whole picnics will be built to withstand the most enormous forces! Snacks will be safer than ever! An simple pot of salad dressing, treated in our laboratories, has been subjected to the impact of a 4,000 pound steam hammer every day for the last sixteen years and has it broken?
Pither | Er....well...
Gulliver | Yes, of course it has...but there are other ideas - the safety straps for sardines for instance.
| A tomato leaps up out of the glove compartment and hovers, then it ejects itself out of the car window
Pither | Here, that tomato just ejected itself.
Gulliver | Really? (embracing Pither excitedly) It works! It works! (the car crashes)
| Fade out. Fade up on country road. Pither is cycling along with Gulliver on the back of the bicycle. Gulliver has his head bandaged and his arm in a sling. Occasionally strains of Clodagh Rogers hit 'Jack in a box' float towards us as Gulliver moves rhythmically.
Pither | (voice over) What a strange turn this cycling tour has taken. Mr Gulliver appears to have lost his memory and far from being interested in safer food is now convinced that he is Clodagh Rogers, the young girl singer. I am taking him for medical attention.
| Cut to Pither and Gulliver cycling into hospital. A sign says 'North Cornwall District Hospital'. Cut to nurse receptionist at a counter with a glass window which lifts up and down. Pither appears.
Pither | Is this the Casualty Department?
Nurse | Yes, that's right.
| Noise of splintering wood and crash out of vision. Pither and the nurse look up. A bench has collapsed in the middle and three patients sitting on it have slid into a heap in the middle. A nurse is on her way to assist. Cut back to Pither and nurse.
Nurse | And what can I do for you?
| The window comes down on her fingers, she winces sharply in pain. She pushes it up again.
Pither | I am at present on a cycling tour of the North Cornwall area taking in Bude and...
Nurse | Could I have your name please?
Pither | Ah, my name is Pither.
Nurse | What?
Pither | P-I-T-H-E-R ...as in Brotherhood, but with PI instead of the BRO and no HOOD.
Nurse | I see...
Pither | I had just visited Taunton...
| Terrific crash. Cut to trolley on its side, and a bandaged patient under a mound of hospital instruments and a nurse standing looking down.
Nurse | Sh!
Pither | ...and was cycling north towards...
Nurse | Yes, where were you injured?
Pither | Just where the A397 Ilfracombe road meets the...
Nurse | On your body...
Pither | Ah no... it's not I who was injured, it's my friend.
| Nurse scowls, crumples up paper, and throws it away. The piece of paper hits a smallish cabinet of glass which topples forward and smashes.
Nurse | Tut... Name?
Pither | Pither.
Nurse | No, no, no, no. Your friend's name.
Pither | Oh, Clodagh Rogers...
Nurse | Clodagh Rogers!?
Pither | Well only since about 4:30....
Nurse | Yes. I think you'd better talk to Doctor Wu... Doctor!
| Cut to a doctor unloading a crate balanced on top of a medicine. He whips round knocking off the crate.
Doctor | What? Damn!
| Cut to patient in a wheelchair being pushed. The wheelchair completely collapses and the nurse is left holding the handles. Quick cut to the nurse as window comes down on her fingers again.
Nurse | Aaaaaagh!
| Doctor comes across to pither, limping slightly, in some pain.
Doctor | Now, what's the trouble?
Pither | I am on a cycling tour of...
Nurse | He thinks he's had an accident.
Pither | I have friend who, as a result of his injuries thinks he is Clodagh Rogers.
Doctor | He what?
Pither | Well, what happened was...
| A nurse carrying a tray walks past the doctor, making for the entrance doors. As she reaches them they swing open to admit Gulliver, with his head bandaged and his arm in a sling. He collides with the nurse; she drops her tray. He graps Pither and they exit rapidly, stepping on the doctor's foot in the process. The doctor yells, grabs his foot, and as he does so the reception window slamms down, trapping his hand. He howls in pain. Cut to a camp fire at midnight in a forest clearing. By the light of the fire, Pither is writing up his diary.
Pither | (voice over) September 4th. Well I never. We are now in the Alpes Maritimes region of Southern France. Clodagh seems more intent on reaching Moscow than on rehearsing her new BBC2 series with Buddy Rich and the Younger Generation...(Gulliver enters the scene; his head is still bandaged) Oh hello!
Gulliver | We cannot stay here. We must leave immediately. There is a ship in Marseilles.
Pither | I did enjoy your song for Europe, Clodagh.
Gulliver | I have seen an agent in the town. My life is in danger.
Pither | Danger, Clodagh?
Gulliver | Stalin has always hated me.
Pither | No one hates you, Clodagh.
Gulliver | I will not let myself fall into the hands of these scum.
Pither | I think you should go and have a little lie down, my dear. There is a busy day tomorrow of concerts and promotional tours.
Gulliver | I. One of the founders of the greatest nation on earth. I! Whom Lenin has called his greatest friend.
| From the darkness we hear French voices.
M. Brun | Taisez-vous. Taisez-vous.
Pither | Oh dear.
Gulliver | I! Who have worked all my life that my people should live.
| A pair of middle class French people in pyjamas appear.
M. Brun | Taisez-vous. Qu'est-ce que le bruit? C'est impossible!
Pither | Er... my name is Pither.
M. Brun | Oh... you are English?
Pither | Er yes, that's right. I'm on a cycling tour of North Cornwall, taking in Bude...
Gulliver | I will not be defeated. I will return to my country to fight against this new tyranny!
Pither | This is Clodagh Rogers, the Irish-born girl singer.
Mme. Brun | Mais oui - c'est Clodagh Rogers - 'Jack-in-a-box'! (sings) I'm just a jack in a box, I know whenever love knocks... (calls) Genevieve! Gerard! C'est Clodagh Rogers la fameuse chanteuse Anglaise.
| Two teenagers in pyjamas and carrying autograph books appear and rush towards Gulliver.
Gulliver | I will never surrender! I will never surrender!...
Genevieve | Excusez-moi Madame Clodagh. Ecrivez-vous votre nom dans mon livre des hommes célèbrites, s'il vous plait. Là, au-dessous de Denis Compton. (Gulliver signs and hands the book back.) Maman! Ce n'est pas la belle Clodagh.
Mme. Brun | Quoi?
Genevieve | C'est Trotsky le révolutionaire.
M. Brun | Trotsky!
Mme. Brun | Mais Trotsky ne chante pas.
M. Brun | Il chante un peu.
Mme. Brun | Mais pas professionalement. Qu'il pense de Lenin.
M. Brun | Ah! Lenin!! Quel chanteur: 'If I ruled the world'.
| A brief film clip of Lenin, apparently singing the next line of the song.
Gulliver | Lenin. My friend. I come.
| He dashes off into the forest possessed.
Pither | Oh excuse her, she's not very well recently, pressure of work, laryngitis, you know...
| He gets on his bike and pedals off hurriedly after Gulliver into the forest.
M. Brun | (still reminiscing) Et aussi Monsieur Kerensky avec le 'Little White Bull', eh?
Mme. Brun | Formidable.
| Cut to a few quick shots of Gulliver dashing through the trees and then of Pither making much slower progress due to his bike. Cut to a shot of a French couple snogging in car.
Gulliver | Lenin! I come! Lenin!
Frenchman | Je t'aime.
French Girl | (seeing Gulliver) Maurice! Regardez! C'est la chanteuse anglaise Clodagh Rogers.
Frenchman | Ah mais oui! (sings) Jacques dans la boîte (he switches on car radio and the song is heard throughout the forest)
| Cut to Russian street. Pither cycles along with Gulliver looking like Trotsky on the back.
Pither | (voice over) After several days I succeeded in tracking down my friend Mr Gulliver on the outskirts of Smolensk.
| Cut to military man. He has a large map of Europe and Russia and a stick with which he raps at the places.
Military Man | Smolensk. 200 miles east of Minsk. 200 north of Kursk. 1500 miles west of Omsk.
| Cut back to Pither and Gulliver.
Pither | Thank you.
| They've stopped by a signpost that says 'Smolensk town centre 1/2, Tavistock 1612 miles'.
Pither | (voice over) Anyway, as we were so far from home, and as Mr Gulliver, still believing himself to be Trotsky, was very tired from haranguing the masses all the way from Monte Carlo,
| Cut to military man who thumps the map again.
Military Man | Monte Carlo. 100 miles south of Turin. 100 east of Pisa. 500 miles west of Bilbao.
| Cut back to Pither.
Pither | Thank you. I decided to check...
Pither | (voice over) I decided to check...
Pither | No, sorry you go on.
Pither | (voice over) I decided to check him into a hotel while I visited the British Embassy to ask for help in returning to Cornwall.
| They leave the bicycle on the kerb and enter a door with the sign 'YMACA.' over it.
Pither | (voice over) And so we registered at the Smolensk Young Men's Anti-Christian Association.
| Cut to military man.
Military Man | YMACA. Corner of Anti-Semitic Street and Pogrom Square.
Pither | (by now standing at the reception desk with Gulliver) Go away. (to departing desk clerk) No, not you. A single room for my friend please.
Desk Clerk | Yes, sir. Bugged or unbugged?
Gulliver | (as Trotsky) I think I'd be happier with a bugged one.
Desk Clerk | Right, one bugged with bath.
Pither | Well, just have a nice lie down, and I'll go to the Embassy.
| He goes. Gulliver signs hotel register.
Desk Clerk | (looking at the book) Trotsky! My lack of God, it's Trotsky!
| A couple of people race in excitedly.
Gulliver | Comrades. Socialism is not a...
| Mix through to the British Consulate. Pither cycles up, parks his bike and goes in. Imperial music. Mix through to interior. A picture of the queen is dimly visible on the back wall. A Chinaman approaches. He is dressed in traditional Mandarin's robe and cap.
Pither | Excuse me. Is this the British Consulate?
Chinaman | Yes yes... si si...that is correctment. Yes... Piccadilly Circus, mini-skirt and Joe Lyons.
Pither | I wish to see the consul, please.
Chinaman | Yes, yes, speakee speakee... me Blitish consul.
Pither | Oh! (he examines his diary.) You are Rear Admiral Sir Dudley Compton?
Chinaman | No. He died. He have heart attack and fell out of window onto exploding bomb, and was killed in a shooting accident. I...I his how you say...succ...sussor.
Pither | Oh, successor.
Chinaman | I'm his successor, Mr Atkinson.
Pither | Oh.
Chinaman | Would you like drinkee? Or game bingo?
Pither | Well.... A drink would be very nice.
| The Chinaman claps his hands and another runs in and bows obsequiously.
Chinaman | Mr. Livingstone. Go and get sake.
Livingstone | Yes, Boss. (goes)
Chinaman | How is Tonblidge Wells? How I long to see again walls of famous Shakespeare-style theatre in Stlatford-on-Avon.
Pither | Oh well, I'm a West Country man myself, Mr. Atkinson.
Chinaman | Oh Texas - Arizona - Kit Carson Super Scout.
Pither | No. No. West of England... Cornwall.
Chinaman | (with difficulty) Coron... worll...
Pither | Cornwall.
Chinaman | Coronworl...oh yes know Coronworl very well. Went to school there, mother and father live there, ah yes. Go many weekend parties and polo playing cards in blidge club. Belong many clubs in Coronworld.
| Livingstone reappears, with drink and plate of pastries. He puts them down.
Chinaman | Ah, Mr Livingstone thank you, sake and bakewells tart. (hands a glass of sake to Pither) Well, chaps, buttocks up!
Pither | Rather. (they drink)
Chinaman | Now then er... er...
Pither | Ah, Pither.
Chinaman | Ah Mr Pither. We Blitish here in Smolensk velly intellested in cliket.
Pither | Oh, cricket?
Chinaman | No, no...you not speak English velly wells. Not clicket - clicket...clicketty click...clicket...housey housey...er, bingo.
Pither | Bingo...
Chinaman | Oh bingo...bingo...bingo.
Livingstone | Bingo! Bingo!
| Several Mao-suited Chinese people rush in waving the Red Book and shouting 'bingo'. The Chinaman remonstrates with Livingstone and eventually stops them.
Chinaman | Hsai! Solly. Our boys got velly excited.(the Maoists exit)
Livingstone | Bingo.
Chinaman | (to Livingstone) Shut face! (to Pither) Mr Pither, perhaps you could put in a good word for so we could join a very smart bingo club in Coronworl.
Pither | Well, it's not really my line...
Chinaman | We all velly quiet at back, not say anything except shout 'Housey! Housey!'
Livingstone | Housey! Housey!
Maoists | (rushing back in) Housey! Housey!
| Cut to stock film of large Chinese crowds.
Chinese Hordes | Housey! Housey! Housey housey!
| Cut back to Consulate. The Chinaman is shouting out of window.
Chinaman | Hi skwwati niyhi, keo t'sin feh t'sdung, hih watai bingo cards! (comes back into room)
Livingstone | Nihi watai bingo cards?
Chinaman | Nihi watai!
Livingstone | Ah so...
Chinaman | Now then, Mr Pither, tell me which better - Hackney Star Bingo or St. Albans Top Rank Suite?
Pither | Well, I was hoping that you could help me and my friend to get back to England as...you see we're on a cycling tour of North Cornwall...
All | Bingo, bingo, bingo...
| The Chinaman ushers Pither out. Brief film of rioting Chinese.
Chinese Hordes | Bingo! Bingo! Bingo! Bingo!
| Cut to hotel lobby.
Pither | Is Mr Trotsky in his room, please?
Desk Clerk | No. He has gone to Moscow.
| Cut to military man.
Military Man | Moscow. 1500 miles south of...
| Cut bach to lobby.
Desk Clerk | Shut up!
Pither | Moscow!
| He is surrounded by three secret policemen dressed in identical suits, dark glasses and pork pie hats.
Grip | Come with us, please.
Pither | Oh, who are you?
Bag | Well we're not secret police anyway.
Wallet | That's for sure.
Grip | If anything we are ordinary Soviet systems with no particular interest in politics.
Bag | None at all. Come with us.
Pither | Oh, where are you taking me?
| The secret police all move away to confer.
Wallet | What do we tell him?
Grip | Don't tell him any secrets.
Bag | Agreed.
Grip | Tell him anything except that we are taking him to Moscow where Trotsky is reunited with the Central Committee.
| They return to Pither.
Wallet | We're taking you to a clambake.
Pither | Oh a clambake! I've never been to one of those.
Grip | Right, let's go.
Bag | Who's giving the orders round here?
Grip | I am. I'm senior to you.
Bag | No, you're not. You're a greengrocer, I'm an insurance salesman.
Grip | Greengrocers are senior to insurance salesmen.
Wallet | Cool it. I'm an ice-cream salesmen and I am senior to both of you.
Bag | You're an ice-cream salesman? I thought you were a vetenarian.
Wallet | I got promoted. Let's go.
Bag | Taxi!
| A girl enters dressed as a New York cabbie.
Taxi | Yes.
Bag | Drive us to Moscow.
Taxi | I have no a cab.
Wallet | Why not?
Taxi | I'm in the Secret Police. (they all snap into salute)
| Cut to stock film of train wheels in the night. The siren sounds. Superimposed names zoom into camera, as in a musical: Petrograd, Ottograd, Lewgrad, Lesliegrad, Etceteragrad, Dukhovskoknabilebskohatsk, Moscva. Cut to the stage of a big Russian hall. A banner across the top of the stage reads 'Russian 42nd International Clambake'. At the back of the stage sits Pither with his bicycle. At one side of the stage, at an impressive table on a dais, are some very important Russian persons including generals. One of the generals addresses the audience.
General | ...Dostoievye useye tovarich trotsky borodina (etc.)
| SUBTITLE: 'THIS IS THE MAN WHO BROUGHT OUR BELOVED TROTSKY BACK TO US'
General | Beluntanks dretsky mihai ovna isky Mr Reg Pither.
| SUBTITLE: 'FIRST MAY I PRESENT MR PITHER FROM WEST OF ENGLAND'
| Pandemonium lasting for about ten seconds.
General | Shi muska di scensand dravenka oblomov Engleska Solzhenitzhin.
| SUBTITLE: 'FORGIVE ME IF I CONTINUE IN ENGLISH IN ORDER TO SAVE TIME'
General | And now, Comrades, the greatest moment of the day, the moment when I ask you to welcome the return of one of Russia's greatest heroes, creator of the Red Army, Lenin's greatest friend, Lev Davidovich Trotsky!
| Gulliver appears looking as much like Trotsky as possible. He wears a uniform and has a beard and glasses. Pandemonium breaks out. He eventually quietens them by raising his hands for silence.
Gulliver | Comrades. Bolsheviks. Friends of the Revolution. I have returned. (renewed cheering) The bloodstained shadow of Stalinist repression is past. I bring you new light of Permanent Revolution (his movements are becoming a little camp and slinky). Comrades, I may once have been ousted from power, I may have been expelled from the party in 1927, I may have been deported in 1929 but (sings) I'm just an old-fashioned girl, with an old-fashioned mind. (a certain amount of confusion is spreading among the audience and particulary the general on the podium) Comrades, I don't want to destroy in order to build, I don't want a state founded on hate and division (sings) I want an old-fashioned house with an old-fashioned fence, and an old-fashioned millionaire.
| From now on Gulliver continues exactly as Eartha Kitt. He has aquired a fur stole which he manipulates slinkily. The confusion is complete on the stage.
Pither | (voice over) Our friend Mr Gulliver was clearly undergoing another change of personality.
| A senior general appears beside Pither with two guards.
General | So! You have duped us. You shall pay for this. Guards, seize him.
| The guards seize the startled Pither and drag him away. The senior general strides back across the stage avoiding Gulliver, towards the general who addressed the audience.
General | Shall I seize him too?
Senior General | No, I think we'll have to keep him, he's going down well.
General | He's more fun than he used to be.
Senior General | He's loosened up a lot. This is an old Lenin number.
| Cut to Pither sitting in a cell.
Pither | (voice over) April 26th. Thrown into Russian cell. Severely damaged my Mars bar. Shall I ever see Bude Bus station again? (two Russian guards throw the cell door open) Oh excuse me... (they grab him and march him out of cell)
| Cut to exterior of a door leading out into prison yard. The door is thrown open and Pither is marched over and stood against a blank wall. There are lots of small holes in the wall.
Pither | (voice over) What a pleasant exercise yard. How friendly they were all being.
Officer | Cigarettes?
Pither | Oh, no thank you I don't smoke.
| Pither facing a line of uniformed men with guns, obviously a firing squad.
Pither | (voice over) After a few minutes I perceived a line of gentlemen with rifles. They were looking in my direction...(cut to Pither against the wall looking behind him) I looked around but could not see the target.
Officer | Blindfold?
Pither | (very cheerful) No thank you, no.
Officer | (stepping clear) Slowotny! (the firing squad snaps to attention) Grydenka... (they raise their rifles) Verschnitzen.
| Drum roll. The firing squad takes aim. A messenger runs frantically up.
Messenger | Nyet! Nyet! Nyet! (he hands the officer a paper)
Officer | A telegram? (examines it) From the Kremlin! The Central Committee! It says...'Carry on with the execution'. Verschnitzen... (The squad raise their rifles)
Pither | (voice over) Now I was really for it.
| Cut to shot of officer with his hand raised. The same as before, only without Pither in shot. Drum rolls again. He brings his sword down. Volley of shots from the firing squad. The officer is looking in Pither's direction. Long pause.
Officer | (to soldiers) How could you miss?
Soldier | He moved.
Officer | Shut up! Go and practise. (to Pither) I'm so sorry. Do you mind waiting in your cell?
| Pither is flung back in his cell by the guards, and the door slammed.
Pither | (voice over) What a stroke of luck. My Crunchie was totally intact. I settled down to a quick intermeal snack...
| But he is bundled out again. Pause. Shots. He si bundled in. The officer appears at door.
Officer | Next time. Definitely! (to aide) Now then, how many of them have been injured? Oh God...
Pither | (voice over) As I lay dwon to the sound of the Russian gentlemen practising their shooting, I realised I was in a bit of a pickle. My heart sank as I realised I should never see the Okehampton by-pass again...
| Mix to Pither's sleeping face, waking up, shaking himself in disbelief at finding himself in a beautiful garden, with the sun shining, the birds singing. He is in a deckchair, and his mother, having poured him a jug of iced fruit juice, is gently nudging Pither to wake him.
Mother | Come on, dear. Wake up dear.
Pither | Mother!
Mother | Come on dear.
Pither | So, it was all a dream.
Mother | No dear, this is the dream, you're still in the cell.
| Mix to Pither waking up in the cell. The officer enters carrying a rifle.
Officer | OK, we're going to have another try. I think we've got it now. My boys have been looking down the wrong bit, you see.
Pither | Oh no, look, you've got to look down the bit there.
Officer | Oh I thought you had to look down that bit.
Pither | No, no, you've got to look down that bit, or you won't hit anything.
Officer | Alright, we'll give it a whirl. Guards, seize him. (they take him out)
Officer | (as he leaves) Listen. You've got to look down this bit.
| As they leave, we can see on the wall of the cell a poster, saying: 'Saturday Night at the Moscow Praesidium, starring Eartha Kitt, with Burgess and Maclean. "A Song a Dance and a Piece of Treachery". Marshal Bulganin and "Charlie", Peter Cook, Dudley Moore, Leningrad has never laughed so much.' Mix through to stock film of the Kremlin. Dubber over laughter and applause. A cheerful band sing. Mix through to stage where someone dressed as Marshall Bulganin, is standing with a little real ventriloquist's dummy. He gets up, takes his bow and walks off as the curtain swings down. Lots of applause and atmosphere. Terrible Russian compère comes on smiling and applauding.
Compère | Osledi Osledi.
| He tells a quick joke in Russian, and roars with laughter. Laughter from audience. He holds up his hands and then becomes very sincere, saying obviously deeply moving, wonderful things about the next guest, whom he finally introduces.
Compère | Eartha Kitt!
| Gulliver comes on-stage in the full Eartha Kitt rig - white fur stole, slit skirt and jewellery. He mimes to the voice of Edward Heath.
Heath's Voice | Trade Union leaders - I would say this - we've done our part. Now, on behalf of the community, we have a right to expect you, the Trade Union leaders, to do yours. (etc.)
| Unrest in the audience as they recognize him. They start shouting 'sing "Old-Fashioned Girl"' and throwing vegetables. Slow motion shot of a tomato hitting Gulliver. He is seen to be holding a turnip.
Gulliver | That turnip's certainly not safe. (looking round and seeing where he is) Oh no! Mr Pither! Mr Pither!
| He runs off-stage, pursued by the guards. Cut to the stage-door of the hall. A sign on the door says 'Next week Clodagh Rogers'. Gulliver out, and then through the streets, hotly pursued by soldiers and secret service men, firing after him.
Gulliver | (calling) Mr Pither! Mr Pither!
| He is seen running through a dockyard. Finally he stops by a high stone wall.
Gulliver | Mr Pither!
Pither's Voice | Here!
| Gulliver looks round and then rapidly climbs up and over the wall. He drops down to find Pither standing on the other side.
Pither | Gulliver.
Gulliver | Pither! What a stroke of luck.
Pither | Well yes and no.
| He indicates with his head. Cut to show that both of them are standing in front of a firing squad. The officer is heard as before. The squard runs towards them with fixed bayonets.
| CAPTION: 'SCENE MISSING'
| Cut to Cornish country lane. A road sign says 'Tavistock 12 miles'. Pither stands beneath with Gulliver and his bicycle.
Pither | Phew, what an amazing escape. Well goodbye, Reginald.
Gulliver | Goodbye, Mr Pither, and good luck with the tour!
| They shake hands. Gulliver strides off. Pither mounts his bike and rides off into the sunset. Music swells. Roll credits. Cut to a field with hedgerow behind. The first animated monster peeks over the hedge.
First Monster | Hey, I think he's finally gone!
| Second monster appears.
Second Monster | Ooh yes!
| They hop over the fence into the field.
First Monster | Ready, Maurice?
Second Monster | Right-ho, Kevin. Let's go.
First Monster | All right, maestro, hit it!
| We hear Clodagh Rogers singing 'Jack in a Box'. The two monsters jump up and down enthusiastically if not gracefully. Fade out.